@@ -18,6 +18,38 @@ def plot2d(lista_vetores, lista_cores, lista_limites):
     plt.axis([lista_limites[0], lista_limites[1], lista_limites[2], lista_limites[3]])
     plt.show()
 
+def check_vector_eqcoord (lista_coord_vetores):
+    comp_x_eq=None
+    comp_y_eq=None
+
+    for i in range(len(lista_coord_vetores)):
+        x = np.array(lista_coord_vetores[i][0][0])
+        y = np.array(lista_coord_vetores[i][0][1])
+        comp_x = lista_coord_vetores[i][1][0] - lista_coord_vetores[i][0][0]
+        comp_y = lista_coord_vetores[i][1][1] - lista_coord_vetores[i][0][1]
+        if (comp_x_eq == None) and (comp_y_eq == None):
+            comp_x_eq = comp_x
+            comp_y_eq = comp_y
+        else:
+            if (comp_x_eq != comp_x) or (comp_y_eq != comp_y):
+                return False
+    return True
+
+def check_vector_eqcomp (lista_vetores):
+    comp_x_eq=None
+    comp_y_eq=None
+
+    for vector in lista_vetores:
+        comp_x = vector[0]
+        comp_y = vector[1]
+        if (comp_x_eq == None) and (comp_y_eq == None):
+            comp_x_eq = comp_x
+            comp_y_eq = comp_y
+        else:
+            if (comp_x_eq != comp_x) or (comp_y_eq != comp_y):
+                return False
+    return True
+
 def plot2d(lista_coord_vetores, lista_cores, lista_limites):
     plt.figure()
     plt.axvline(x=0, color='#A9A9A9', zorder=0)
@@ -54,4 +86,4 @@ def plot3d(lista_vetores, lista_cores, lista_limites):
     for vector in lista_vetores:
         ax.quiver(0, 0, 0, vector[0], vector[1], vector[2], length=1, normalize=False, color=lista_cores[i])
         i += 1
-    plt.show()
+    plt.show()
\ No newline at end of file
